%global momorel 2
Summary: GNU Scientific Library (GSL)
name: gsl
Version: 1.8
Release: %{momorel}m
URL: http://sources.redhat.com/gsl/
%NoSource 0 ftp://ftp.gnu.org/gnu/gsl/%{name}-%{version}.tar.gz c60a5d193cc6b472496ff191744fc306
License: GPL
Group: Development/Libraries
Prereq: info
BuildPreReq: sed
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
The GNU Scientific Library (GSL) is a numerical library for C and C++
programmers. It contains over 1000 mathematical routines written in ANSI
C. The library follows modern coding conventions, and lends itself to
being used in very high level languages (VHLLs).

The library covers the following subject areas:

  Complex Numbers             Roots of Polynomials     Special Functions
  Vectors and Matrices        Permutations             Sorting
  BLAS Support                Linear Algebra           Eigensystems
  Fast Fourier Transforms     Quadrature               Random Numbers
  Quasi-Random Sequences      Random Distributions     Statistics
  Histograms                  N-Tuples                 Monte Carlo Integration
  Simulated Annealing         Differential Equations   Interpolation
  Numerical Differentiation   Chebyshev Approximation  Series Acceleration
  Discrete Hankel Transforms  Root-Finding             Minimization
  Least-Squares Fitting       Physical Constants       IEEE Floating-Point

Further information can be found in the GSL Reference Manual.

Install the gsl package if you need a library for high-level
scientific numerical analysis.

%prep
%setup -q

%build
#  compiler options for all architecture
CFLAGS=`echo %{optflags} | sed s/-ffast-math//` ; export CFLAGS
CXXFLAGS=`echo %{optflags} | sed s/-ffast-math//` ; export CXXFLAGS
FFLAGS=`echo %{optflags} | sed s/-ffast-math//` ; export FFLAGS
#  We have to get rid of the -ffast-math option to get IEEE compatible
#  numeric handling. Otherwise, `make check' fails.
#  (1.0-2k, zunda <zunda@kondara.org>)
#
#  with -ffast-math, 'make check' failed (gsl-1.2-3m,gcc-3.2-1m by zaki).

#  architecture dependent compiler options
# last -O? is effective
%ifarch alpha ppc
CFLAGS="   $CFLAGS   -O1"
CXXFLAGS=" $CXXFLAGS -O1"
FFLAGS="   $FFLAGS   -O1"
#  `make check' fails with the -O2 option on alpha machines.
#  (1.0-2k, zunda <zunda@kondara.org>)
%endif
%ifarch %ix86
### intel machines
CFLAGS=`  echo $CFLAGS   | sed s/i686/i586/g`
CXXFLAGS=`echo $CXXFLAGS | sed s/i686/i586/g`
FFLAGS=`  echo $FFLAGS   | sed s/i686/i586/g`
#  make check fails on intel/Sinji with i686 option (gsl-1.7-3m, gcc-4.1.0-0.6m by ichiro)
#
#CFLAGS=`  echo $CFLAGS   -ffloat-store -O2 | sed s/i686/i586/g`
#CXXFLAGS=`echo $CXXFLAGS -ffloat-store -O2 | sed s/i686/i586/g`
#FFLAGS=`  echo $FFLAGS   -ffloat-store -O2 | sed s/i686/i586/g`
#  make check fails on intel/jirai with i686 option even on an i686 machine
#  (1.0-3.020020225001k, zunda <zunda@kondara.org>)
#
#  without -ffloat-store on ix86, 'make check' failed.    (gsl-1.2-3m,gcc-3.2-1m by zaki)
#  with    -O2 on ix86,           'make check' succeeded. (gsl-1.2-3m,gcc-3.2-1m by zaki)
# fails with -ffloat-store (on P4 with gsl-1.6-1m and gcc-3.4.3-5m by zunda)
%endif

./configure %{_target_platform} --prefix=%{_prefix}
%make
%ifnarch ia64 alpha
%make check
%endif
#  It might be a good idea to check compilation everytime we rebuild the
#  package, because the result strongly depends upon the compile options,
#  which changes upon rebuild even if it takes time. Otherwise the
#  library may return false values. When the check fails, check the
#  compiler options first and the file INSTALL in the source directory
#  would help you.
#  (1.0-2k, zunda <zunda@kondara.org>)

%install
rm -rf %{buildroot}
%makeinstall

# remove
%__rm -f %{buildroot}%{_infodir}/dir

# for multilib
gslcsuffix=`echo "%{_libdir}" | sed s,/usr/,,`
mv %{buildroot}%{_bindir}/gsl-config %{buildroot}%{_bindir}/gsl-config-$gslcsuffix
cat > %{buildroot}%{_bindir}/gsl-config << EOF
#!/bin/sh
if [ -e %{_bindir}/gsl-config-lib64 ]; then
  exec %{_bindir}/gsl-config-lib64 "\$@"
elif [ -e %{_bindir}/gsl-config-* ]; then
  gslcfile="\`ls %{_bindir}/gsl-config-* | head -n1\`"
  exec \$gslcfile "\$@" 
fi
EOF
chmod 755 %{buildroot}%{_bindir}/gsl-config

%post
/sbin/install-info %{_infodir}/gsl-ref.info.* %{_infodir}/dir
/sbin/ldconfig -n %{_libdir}

%postun -p /sbin/ldconfig

%preun
if [ "$1" = 0 ]; then
  /sbin/install-info --delete %{_infodir}/gsl-ref.info.* %{_infodir}/dir
fi

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog NEWS THANKS COPYING INSTALL
%doc README TODO BUGS
%{_infodir}/gsl-ref*
%{_bindir}/*
%{_libdir}/lib*
%{_libdir}/pkgconfig/*.pc
%{_datadir}/aclocal/*
%{_includedir}/*
%{_mandir}/man1/*
%{_mandir}/man3/*

%changelog
* Tue May 23 2006 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.8-2m)
- delete duplicated dir

* Thu Apr 20 2006 Masayuki SANO <nosanosa@momonga-linux.org>
- (1.8-1m)
- update to 1.8
- revised for multilib (like FC)

* Wed Jan 18 2006 Ichiro Nakai <ichiro@n.email.ne.jp>
- (1.7-3m)
- modify optflags s/i686/i586/ for gcc-4.1.0-0.6m

* Mon Oct 17 2005 Dai OKUYAMA <dai@ouchi.nahi.to>
- (1.7-2m)
- enable ia64, alpha

* Fri Sep 16 2005 zunda <zunda at freeshell.org>
- (1.7-1m)
- source update
- tested with gcc-3.4.3-16m on a Pentum 4 as i686

* Sun Jan 30 2005 zunda <zunda at freeshell.org>
- (1.6-1m)
- source update
- tested with gcc-3.4.3-5m on a Pentum 4 as i686

* Sun Jan  8 2005 Toru Hoshina <t@momonga-linux.org>
- (1.5-2m)
- force gcc 3.2.3.

* Tue Aug 10 2004 zunda <zunda at freeshell.org>
- (1.5-1m)
- source update
- Patch0: gsl-1.4-gsl_const.patch removed

* Sat Mar 20 2004 Toru Hoshina <t@momonga-linux.org>
- (1.4-3m)
- revised spec for enabling rpm 4.2.

* Tue Sep 16 2003 zunda <zunda at freeshell.org>
- (1.4-2m)
- bug in gsl/const.h fixed with gsl-1.4-gsl_const.patch

* Thu Sep 11 2003 zunda <zunda at freeshell.org>
- (1.4-1m)
- source update, tested on a Pentium 4

* Thu Jan  9 2003 zunda <zunda@freeshell.org>
- (1.3-1m, kossori)
- removed MACHINES file from %doc: it has been merged into INSTALL

* Thu Jan  9 2003 zunda <zunda@freeshell.org>
- (1.3-1m) 
- source update: Changed interface for gsl_sf_coupling_6j...(...) etc.
- MACHINES file is missing in the source tar ball
- make test passes at least on an Athlon with gcc-3.2-8m

* Mon Oct  7 2002 YAMAZAKI Makoto <uomaster@nifty.com>
- (1.2-3m)
- compile option tuning for gcc-3.2
- use gcc-3.2 on ppc

* Mon Sep 30 2002 Kazuhiko <kazuhiko@fdiary.net>
- (1.2-2m)
- use gcc_2_95_3 on ppc

* Thu Jul 25 2002 Tsutomu Yasuda <tom@tom.homelinux.org>
- (1.2-1m)
  update to 1.2

* Thu May 30 2002 YAMAZAKI Makoto <zaki@kondara.org>
- (1.1.1-8k)
- cancel gcc-3.1 autoconf-2.53

* Tue Apr 23 2002 zunda <zunda@kondara.org>
- (1.1.1-6k)
- gsl_qrng_init from gsl-discuss <5556.22035.593447.329481@debian>

* Tue Apr 16 2002 zunda <zunda@kondara.org>
- (1.1.1-4k)
- gsl_rng_mt19937_1998 was missing in gsl/gsl_rng.h

* Sun Mar 17 2002 zunda <zunda@kondara.org>
- (1.1.1-2k)
- source update

* Tue Mar  5 2002 zunda <zunda@kondara.org>
- (1.1-2k)
- source update
- description copied from gsl.spec.in in gsl-1.1.tar.gz

* Mon Feb 25 2002 zunda <zunda@kondara.org>
- (1.0-3.020020225001k)
- CVS version of gsl
- compiler option adaptation for Jirai

* Thu Feb 21 2002 zunda <zunda@kondara.org>
- (1.0-2k)
- OmoiKondarize
- literal %configure procedure copied from macro file in rpm-3.0.6-44k
  to avoid -ffast-math option

* Thu Nov 24 2001 zunda <zunda@m-net.arbornet.org>
- (1.0-3z) Info did not install correctly

* Thu Nov 20 2001 zunda <zunda@m-net.arbornet.org>
- (1.0-2z) Changed doc list not to include the file ../info/dir

* Thu Nov  7 2001 zunda <zunda@m-net.arbornet.org>
- (1.0-1z) Update

* Thu Oct 30 2001 zunda <zunda@m-net.arbornet.org>
- (0.9.4-1z) Update

* Thu Sep  6 2001 zunda <zunda@m-net.arbornet.org>
- (0.9.2-1z) Update

* Sun Aug 26 2001 zunda <zunda@m-net.arbornet.org>
- (0.9.1-1z) Merged specfiiles from gsl-0.9.1-0 and gsl-0.9-1z

* Thu Jul 12 2001 zunda <zunda@m-net.arbornet.org>
- (0.9-1z) Merged specfile in gsl-0.9-0.src.rpm
- rm -rf $RPM_BUILD_ROOT adddd after %install to avoid hunging in gzipping

* Mon Apr 16 2001 zunda <zunda@m-net.arbornet.org>
- (0.7-1z)
- Kondarize

* Thu Jan 18 2001 Preston Brown <pbrown@redhat.com>
- prereq install-info (#24250)

* Mon Dec 11 2000 Preston Brown <pbrown@redhat.com>
- 0.7, remove excludearch for ia64

* Sun Jul 30 2000 Florian La Roche <Florian.LaRoche@redhat.de>
- fix %post to be a real shell and add ldconfig to %post

* Thu Jul 13 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Mon Jun 19 2000 Preston Brown <pbrown@redhat.com>
- don't include the info dir file...

* Sat Jun 17 2000 Bill Nottingham <notting@redhat.com>
- add %%defattr

* Mon Jun 12 2000 Preston Brown <pbrown@redhat.com>
- 0.6, FHS paths
- exclude ia64, it is having issues

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 2)

* Thu Mar 11 1999 Bill Nottingham <notting@redhat.com>
- update to 0.3f
- add patches to fix glibc-2.1 compilation, doc oddity

* Thu Feb 25 1999 Bill Nottingham <notting@redhat.com>
- new summary/description, work around automake oddity

* Tue Jan 12 1999 Michael K. Johnson <johnsonm@redhat.com>
- libtoolize for arm

* Thu Sep 10 1998 Cristian Gafton <gafton@redhat.com>
- spec file fixups

* Sat May 9 1998 Michael Fulbright <msf@redhat.com>
- started with package for gmp from Toshio Kuratomi <toshiok@cats.ucsc.edu>
- cleaned up file list
- fixed up install-info support
